/* AbiSource Program Utilities
 * Copyright (C) 1998 AbiSource, Inc.
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
 * 02111-1307, USA.
 */
 


#ifndef UT_STACK_H
#define UT_STACK_H

#include "ut_types.h"
#include "ut_vector.h"

class ABI_EXPORT UT_Stack
{
public:
	bool			push(void * pVoid);
	bool			pop(void ** ppVoid);
	bool			viewTop(void ** ppVoid) const;
	UT_uint32		getDepth(void) const;

private:
	UT_Vector		m_vecStack;
};

#endif /* UT_STACK_H */
